[chronojump] Sprint export checks if DataIsOk same way that sprint graph does
- From: Xavier de Blas <xaviblas src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [chronojump] Sprint export checks if DataIsOk same way that sprint graph does
- Date: Mon, 21 Feb 2022 11:31:49 +0000 (UTC)
commit 89702b561019ad5388e60d0380a4103b1fc5ee7d
Author: Xavier de Blas <xaviblas gmail com>
Date: Mon Feb 21 12:24:28 2022 +0100
Sprint export checks if DataIsOk same way that sprint graph does
src/exportFiles/sprint.cs | 13 ++++++++++++-
1 file changed, 12 insertions(+), 1 deletion(-)
---
diff --git a/src/exportFiles/sprint.cs b/src/exportFiles/sprint.cs
index 9fabc194c..76ba34e3e 100644
--- a/src/exportFiles/sprint.cs
+++ b/src/exportFiles/sprint.cs
@@ -134,8 +134,19 @@ public class SprintExport : ExportFiles
if(splitTimes.Split(new char[] {';'}).Length < 3)
continue;
- // create the export row
+ //discard sprints that are not sprint
+ SprintRGraph sprintRGraph = new SprintRGraph (
+ positions,
+ splitTimes,
+ ps.Weight, //TODO: can be more if extra weight
+ ps.Height,
+ "",
+ 25);
+ if(! sprintRGraph.IsDataOk())
+ continue;
+
+ // create the export row
string title = Util.ChangeSpaceAndMinusForUnderscore(p.Name) + "-" +
Util.ChangeSpaceAndMinusForUnderscore(ri.Type);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]